@@ -22,6 +22,7 @@ from .runtime import NativeRuntime
 from .package import MetaflowPackage
 from .plugins import LOGGING_SIDECAR, MONITOR_SIDECAR
 from .metadata import METADATAPROVIDERS
+from .metaflow_config import DEFAULT_DATASTORE, DEFAULT_METADATA
 from .plugins import ENVIRONMENTS
 from .environment import MetaflowEnvironment
 from .pylint_wrapper import PyLint
@@ -658,7 +659,7 @@ def version(obj):
               default=False,
               help='Suppress unnecessary messages')
 @click.option('--metadata',
-              default='local',
+              default=DEFAULT_METADATA,
               show_default=True,
               type=click.Choice([m.TYPE for m in METADATAPROVIDERS]),
               help='Metadata service type')
@@ -668,7 +669,7 @@ def version(obj):
               type=click.Choice(['local'] + [m.TYPE for m in ENVIRONMENTS]),
               help='Execution environment type')
 @click.option('--datastore',
-              default='local',
+              default=DEFAULT_DATASTORE,
               show_default=True,
               type=click.Choice(DATASTORES),
               help='Data backend type')
@@ -840,7 +841,7 @@ def main(flow, args=None, handle_exceptions=True, entrypoint=None):
     import warnings
     warnings.filterwarnings('ignore')
     if entrypoint is None:
-        entrypoint = [sys.executable, '-u', sys.argv[0]]
+        entrypoint = [sys.executable, sys.argv[0]]
 
     state = CliState(flow)
     state.entrypoint = entrypoint
