@@ -184,7 +184,7 @@ class MetaflowDataStore(object):
 
     def get_log_location(self, logtype, attempt_override=None):
         """
-        Return a string indicating the location of the log of the specified type.
+        Returns a string indicating the location of the log of the specified type.
         """
         filename = self.filename_with_attempt_prefix(
             '%s.log' % logtype, attempt_override if attempt_override is not None else self.attempt)
@@ -202,7 +202,7 @@ class MetaflowDataStore(object):
     @classmethod
     def decode_gzip_data(cls, filename, fileobj=None):
         """
-        Return the gzip data in file with `filename` or passed via `fileobj`.
+        Returns the gzip data in file with `filename` or passed via `fileobj`.
         """
         with gzip.GzipFile(filename, fileobj=fileobj, mode='rb') as f:
             return f.read()
@@ -327,7 +327,11 @@ class MetaflowDataStore(object):
         if run_id == 'data':
             raise DataException("Run ID 'data' is reserved. "
                                 "Try with a different --run-id.")
-
+        if self.datastore_root is None:
+            raise DataException("Datastore root not found. "
+                                "Specify with DATASTORE_SYSROOT_%s "
+                                "environment variable." % self.TYPE.upper())
+        
         self.event_logger = event_logger
         self.monitor = monitor
         self.metadata = metadata
@@ -345,11 +349,12 @@ class MetaflowDataStore(object):
         if self.artifact_cache is None:
             self.artifact_cache = {}
 
+        self.data_root = os.path.join(self.datastore_root, flow_name, 'data')
         self.root = self.make_path(flow_name,
                                    run_id,
                                    step_name,
                                    task_id)
-        self.data_root = os.path.join(self.datastore_root, flow_name, 'data')
+
         self.attempt = attempt
         if mode == 'w':
             if run_id is not None:
