@@ -16,14 +16,9 @@ from ..metadata import MetaDatum
 class LocalDataStore(MetaflowDataStore):
     TYPE = 'local'
 
-    # The LocalDataStore can be used both to save artifacts and to store execution metadata
-    # (used by the client). In the latter case, we reserve a directory for the metadata to be
-    # stored.
     METADATA_DIR = '_meta'
 
     def _makedirs(self, path):
-        # this is for python2 compatibility.
-        # Python3 has os.makedirs(exist_ok=True).
         try:
             os.makedirs(path)
         except OSError as x:
@@ -60,7 +55,7 @@ class LocalDataStore(MetaflowDataStore):
             if top_level_reached:
                 if create_on_absent:
                     # Could not find any directory to use so create a new one
-                    echo('Creating local metaflow directory in current directory (%s)' % orig_path,
+                    echo('Creating local datastore in current directory (%s)' % orig_path,
                          fg='magenta', bold=True)
                     os.mkdir(orig_path)
                     result = orig_path
@@ -70,8 +65,6 @@ class LocalDataStore(MetaflowDataStore):
                 result = check_dir
         else:
             result = os.path.join(result, DATASTORE_LOCAL_DIR)
-        # echo('Using %s as Metaflow\'s local data and metadata directory' % result,
-        #      fg='green', bold=True)
         return result
 
     @classmethod
