@@ -26,7 +26,7 @@ except:
     # python3
     from urllib.parse import urlparse
 
-from ..metaflow_config import get_authenticated_boto3_session
+from ..metaflow_config import get_authenticated_boto3_client
 from botocore.exceptions import ClientError
 
 NUM_S3OP_RETRIES = 8
@@ -197,7 +197,6 @@ class S3(object):
             tmproot: (optional) Root path for temporary files (default: '.')
         """
 
-        self._session = get_authenticated_boto3_session()
         if run:
             # 1. use a (current) run ID with optional customizations
             parsed = urlparse(DATATOOLS_S3ROOT)
@@ -537,7 +536,7 @@ class S3(object):
                                      prefix='metaflow.s3.one_file.',
                                      delete=False)
             try:
-                s3 = self._session.client('s3')
+                s3 = get_authenticated_boto3_client('s3')
                 op(s3, tmp.name)
                 return tmp.name
             except ClientError as err:
