@@ -111,7 +111,7 @@ class FlowSpec(object):
 
         Returns
         -------
-        Iterator of graph.DAGNode
+        Iterator[graph.DAGNode]
             Iterator over the steps in the flow
         """
         return iter(self._steps)
