@@ -26,7 +26,7 @@ class InternalFile():
         else:
             extra = ''
         self._logger(
-            'Loading and saving file %s of size %d%s %s' % (self._path, sz, unit[pos], extra))
+            'Including file %s of size %d%s %s' % (self._path, sz, unit[pos], extra))
         if self._is_text:
             return io.open(self._path, mode='rt', encoding=self._encoding).read()
         try:
@@ -58,7 +58,7 @@ class FilePathClass(click.ParamType):
         except OSError:
             self.fail("Could not open file '%s'" % value)
 
-        return InternalFile(ctx.obj.echo, self._is_text, self._encoding, value)
+        return InternalFile(ctx.obj.logger, self._is_text, self._encoding, value)
 
     def __str__(self):
         return repr(self)
