@@ -369,16 +369,7 @@ class NativeRuntime(object):
                 worker = self._workers.get(event.fd)
                 if worker:
                     if event.can_read:
-                        # Try to read as many loglines as possible within reason. The reason we
-                        # read more than one is to attempt to avoid interleaving lines from
-                        # stdout and stderr. If a process writes to both stdout and stderr,
-                        # reading only one line at a time will almost guarantee some form of 
-                        # mingling which can be confusing to the user. There is clearly
-                        # no guarantee of course but this seems to improve output for
-                        # confusing use cases
-                        max_lines = 64
-                        while max_lines > 0 and worker.read_logline(event.fd):
-                            max_lines -= 1
+                        worker.read_logline(event.fd)
                     if event.is_terminated:
                         returncode = worker.terminate()
 
