@@ -59,8 +59,8 @@ class PlayListFlow(FlowSpec):
         # Load the analysis from the MovieStatsFlow.
         from metaflow import Flow, get_metadata
 
-        # Print working tree
-        print("Using working tree: %s" % get_metadata())
+        # Print metadata provider
+        print("Using metadata provider: %s" % get_metadata())
 
         # Load the analysis from the MovieStatsFlow.
         run = Flow('MovieStatsFlow').latest_successful_run
